function simulate(omc, model; StartTime = 0,
        StopTime = 0, Tolerance = 1E-6,
        NumberOfIntervals = 500, simDir = "/tmp/OpenModelica", verbose = false)
    # Assemble options
    simulateOpts = ", tolerance=" * string(Tolerance)
    if StartTime != 0
        simulateOpts *= ", startTime=" * string(StartTime)
    end
    if StopTime > StartTime
        simulateOpts *= ", stopTime=" * string(StopTime)
    end
    if NumberOfIntervals != 500
        simulateOpts *= ", numberOfIntervals=" * string(NumberOfIntervals)
    end

    # Switch to simulation directory
    localDir = pwd()
    if isdir(simDir)
        cd(simDir)
        OMJulia.sendExpression(omc, "cd(\"" * simDir * "\")")
    end

    # Run simulaton
    if verbose
        print("    simulate("*model*simulateOpts*")")
    end
    status = OMJulia.sendExpression(omc, "simulate(" * model * simulateOpts * ")")

    # Switch back to local directory
    cd(localDir)
    OMJulia.sendExpression(omc, "cd(\"" * localDir * "\")")

    if status != ""
        # Report successful operation
        if verbose
            println(" ... successful")
        end
        resultFile = get(status, "resultFile", nothing)
        if verbose
            println("    Result file:")
            println("    " * resultFile)
            return(resultFile)
        end
    else
        messages = get(status, "messages",nothing)
        if verbose
            # Indicate failed operation and print status message
            println(" ... failed")
            println("    Status: " * messages)
        end
        return(false)
    end
end
